==> kafka-3.9.2-src.tgz: kafka-3.9.2-src/clients/src/main/java/org/apache/kafka/common/errors/NotCoordinatorException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.common.errors;

/**
 * In the context of the group coordinator, the broker returns this error code if it receives an offset fetch
 * or commit request for a group it's not the coordinator of.
 *
 * In the context of the transactional coordinator, it returns this error when it receives a transactional
 * request with a transactionalId the coordinator doesn't own.
 */
public class NotCoordinatorException extends RetriableException {

    private static final long serialVersionUID = 1L;

    public NotCoordinatorException(String message) {
        super(message);
    }

    public NotCoordinatorException(String message, Throwable cause) {
        super(message, cause);
    }

}

==> kafka-4.1.0-src.tgz: kafka-4.1.0-src/clients/src/main/java/org/apache/kafka/common/errors/NotCoordinatorException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.common.errors;

/**
 * In the context of the group coordinator, the broker returns this error code if it receives an offset fetch
 * or commit request for a group it's not the coordinator of.
 *
 * In the context of the transactional coordinator, it returns this error when it receives a transactional
 * request with a transactionalId the coordinator doesn't own.
 */
public class NotCoordinatorException extends RefreshRetriableException {

    private static final long serialVersionUID = 1L;

    public NotCoordinatorException(String message) {
        super(message);
    }

    public NotCoordinatorException(String message, Throwable cause) {
        super(message, cause);
    }

}
